@@ -76,10 +76,10 @@ class result:
                                     show_ol = False,
                                     phase1 = None,
                                     phase2 = None,
-                                    dpi = 500,
-                                    figsize = [9.6, 7.2],
+                                    dpi = 100,
+                                    figsize = [8., 6.],
                                     usetex = True,
-                                    fontsize = 20,
+                                    fontsize = 14.,
                                     grid = True,
                                     linewidth = 2.,
                                     show_legend = True)
@@ -112,24 +112,24 @@ class result:
     @property 
     def x_cl(self):
         """numpy.ndarray : Closed loop trajectory."""
-        return self._x_cl
+        return self._x_cl.A
     
     @property 
     def u_cl(self):
         """numpy.ndarray : Closed loop feedback."""
-        return self._u_cl
+        return self._u_cl.A
     
     @property 
     def l_cl(self):
         """numpy.ndarray : Stage costs evaluated at the 
         closed loop trajectory and feedback."""
-        return self._l_cl
+        return self._l_cl.A
     
     @property 
     def t_cl(self):
         """numpy.ndarray : Time sequence at which the 
         closed loop states and controls are evaluated."""
-        return self._t_cl
+        return self._t_cl.A
     
     @property 
     def x_ol(self):
@@ -342,15 +342,15 @@ class result:
         |                      |                                                 |                   |
         |                      |Will be ignored if args!='phase'.                |                   |
         +----------------------+-------------------------------------------------+-------------------+
-        |dpi                   |resolution of the figure, see                    | 500               |
+        |dpi                   |resolution of the figure, see                    | 100               |
         +----------------------+-------------------------------------------------+-------------------+
-        |figsize               |The size of the figure.                          | [9.6, 7.2]        |
+        |figsize               |The size of the figure.                          | [8., 6.]          |
         |                      |                                                 |                   |
         |                      |Has the form  [width, height] in inches.         |                   |
         +----------------------+-------------------------------------------------+-------------------+
         |linewidth             |Set the line width in points.                    | 2.                |
         +----------------------+-------------------------------------------------+-------------------+
-        |fontsize              |The font size of the annotations.                | 20                |
+        |fontsize              |The font size of the annotations.                | 14.               |
         |                      |                                                 |                   |
         |                      |If the value is numeric the size will be the     |                   |
         |                      |                                                 |                   |
